/***********************************************************************
 *                copyright 2004, Amoco Production Company             *
 *                            All Rights Reserved                      *
 *                    an affiliate of BP America Inc.                  *
 ***********************************************************************/
int builtin(name) /* return true if name is /bin/sh built-in */
register char *name;
{
	register char **p;

	static char *table[] = {
		"(",
		"case",
		"cd",
		"echo",
		"exec",
		"exit",
		"export",
		"for",
		"if",
		"pwd",
		"set",
		"test",
		"trap",
		"unset",
		"wait",
		"while",
		":",
		"{",
		".",
		0
	};

	for (p = table; *p; p++)
		if (strcmp(name,*p) == 0)
			return 1;

	return 0;

}
